>From 49dd7345df075ddf8680c590fbe858cfb55e5138 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Filip=20Ros=C3=A9en?= <filip@videolabs.io>
Date: Sat, 4 Jun 2016 14:52:04 +0200
Subject: [PATCH] stream_filter/cache_block: fix premature EOF

AStreamReadBlock would potentially return 0 because the current data block
(denoted by "p_sys->p_current") was exhausted, even though there might be more
data in the next data block ("p_sys->p_current->p_next").

At the place where this patch apply, `p_sys->p_current` has been set to
`p_sys->p_current->p_next`, so the pointer denotes the next block to
process (even though the name is rather misleading at that point).

---
 modules/stream_filter/cache_block.c | 10 ++++++++++
 1 file changed, 10 insertions(+)

diff --git a/modules/stream_filter/cache_block.c b/modules/stream_filter/cache_block.c
index dc31506..7695fac 100644
--- a/modules/stream_filter/cache_block.c
+++ b/modules/stream_filter/cache_block.c
@@ -402,6 +402,16 @@ static ssize_t AStreamReadBlock(stream_t *s, void *buf, size_t len)
             AStreamRefillBlock(s);
     }
 
+    /**
+     * we should not signal end-of-file if we have not exhausted
+     * the blocks we know about, as such we should try again if that
+     * is the case. i_copy == 0 just means that the processed block does
+     * not contain data at the offset that we want, not EOF.
+     **/
+
+    if( i_copy == 0 && sys->p_current )
+        return AStreamReadBlock( s, buf, len );
+
     sys->i_pos += i_copy;
     return i_copy;
 }
-- 
2.8.3

